<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+272"/>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>Tuuma</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>Jalka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>Maili</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>Millimetri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>Senttimetri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>Metri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>Kilometri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>Mikrotuuma</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>Maili</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>Jaardi</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>Ångström</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>Nanometri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>Mikroni</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>Desimetri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>Dekametri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>Hehtometri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>Gigametri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>Astronominen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>Valovuosi</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>Parsek</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+340"/>
        <source>By Layer</source>
        <translation>Tason mukaan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Lohkon mukaan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>Punainen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Green</source>
        <translation>Vihreä</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Blue</source>
        <translation>Sininen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cyan</source>
        <translation>Sinivihreä</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Magenta</source>
        <translation>Purppura</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yellow</source>
        <translation>Keltainen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Orange</source>
        <translation>Oranssi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Tummanpunainen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Tummanvihreä</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Tummansininen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Tumma sinivihreä</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Tumma purppura</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Tummankeltainen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>Musta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gray</source>
        <translation>Harmaa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>Vaaleanharmaa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation>Valkoinen</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Others...</source>
        <translation>Muut ...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+48"/>
        <source>Current Layer ID</source>
        <translation>Nykyisen tason tunniste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Piirtoyksikkö</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Viivatyypin mittakaava</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Kirjasimen mitta</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/REntity.cpp" line="+95"/>
        <source>Block</source>
        <translation>Lohko</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+102"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+80"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+75"/>
        <source>Pixel Unit</source>
        <translation>Pikseliyksikkö</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+83"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+75"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Nollapiste</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Asettelu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Owned by Reference</source>
        <translation>Omistaa Viite</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External reference</source>
        <translation>Ulkoinen viite</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-7"/>
        <source>Referenced Block</source>
        <translation>Viitattu lohko</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External Reference</source>
        <translation>Ulkoinen viite</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translation>Mittakaava</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>Kulma</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Sarakkeet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Rivit</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Sarakeväli</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Riviväli</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Määritteet</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="-1"/>
        <location filename="../src/core/RObject.cpp" line="+70"/>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layer</source>
        <translation>Taso</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+104"/>
        <source>Linetype</source>
        <translation>Viivatyyppi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Viivatyypin mittakaava</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>Viivan paksuus</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>Väri</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Näytetty väri</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation>Piirtojärjestys</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Parent Id</source>
        <translation>Vanhemman tunnus</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Rajaviiva</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Vasen</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Alapuoli</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Oikea</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Yläpuoli</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+162"/>
        <source>Custom</source>
        <translation>Mukautettu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Kahva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Suojattu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Selected</source>
        <translation>Valittu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Object Invisible</source>
        <translation>Näkymätön esine</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Working Set</source>
        <translation>Työsarja</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Leveys</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Korkeus</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Yksinkertainen</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Tekstin sijainti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Teksti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Tavallinen teksti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Kirjasimen nimi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Tekstin korkeus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Width</source>
        <translation>Tekstin leveys</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Tekstin kulma</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>X mittakaava</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Lihavoitu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Kursiivi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Riviväli</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Tasaus</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Vaakasuunta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Pystysuunta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Backward</source>
        <translation>Takaisin</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Upside Down</source>
        <translation>Ylösalaisin</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Kierto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>Päälle</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Näytä keskiosa</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Näytä kohde</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>Yleistä</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Frozen Layers</source>
        <translation>Jäädytetyt kerrokset</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer ID</source>
        <translation>Kerroksen tunnus</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-8"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayerState.cpp" line="+46"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Piilotettu</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>Pois</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Jäädytetty</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Lukittu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Kutistettu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Piirturilla</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Tarttuva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>Pois on jäädytetty</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>Välilehden järjestys</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Minimirajat</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Maksimirajat</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>Lisäysalusta</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Pienin määrä</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Suurin määrä</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+920"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>Pyöreä (rekursiivinen) lohkoviittaus havaittu:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Lohkon nimi:</translation>
    </message>
    <message>
        <location filename="../src/core/RDimStyle.cpp" line="+71"/>
        <source>Style</source>
        <translation>Tyyli</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Overall scale</source>
        <translation>Yleinen asteikko</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear measurement factor</source>
        <translation>Lineaarinen mittauskerroin</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text height</source>
        <translation>Tekstin korkeus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line gap</source>
        <translation>Mittaviivan rako</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow size</source>
        <translation>Nuolen koko</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line increment</source>
        <translation>Mittaviivan lisäys</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line extension</source>
        <translation>Laajennuslinjan laajennus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line offset</source>
        <translation>Jatkojohdon offset</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text position vertical</source>
        <translation>Tekstin sijainti pystysuunnassa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text horizontal</source>
        <translation>Teksti vaakasuorassa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tick size</source>
        <translation>Rastin koko</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear format</source>
        <translation>Lineaarinen muoto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal places</source>
        <translation>Desimaaliluvut</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal separator</source>
        <translation>Desimaalierotin</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zero suppression</source>
        <translation>Nollasuppressio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular format</source>
        <translation>Angular-muoto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular decimal places</source>
        <translation>Kulmamääräiset desimaaliluvut</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular zero suppression</source>
        <translation>Kulman nollakohdan tukahduttaminen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectur tick</source>
        <translation>Arkkitehtuurin rasti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text color</source>
        <translation>Tekstin väri</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block</source>
        <translation>Nuolilohko</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 1</source>
        <translation>Nuolilohko 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 2</source>
        <translation>Nuolilohko 2</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+203"/>
        <source>Requires selection</source>
        <translation>Vaatii valinnan</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+51"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Kuvaus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Metrinen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Kuvio</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+912"/>
        <source>By Layer</source>
        <translation>Tason mukaan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Lohkon mukaan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Jatkuva</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Reuna</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Keskipiste</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Pisteviiva</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Katkoviiva</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Jaa</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Piste</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Piilotettu</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Haamu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISO ajatusviiva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO ajatusviiva - välilyönti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO pitkä ajatusviiva - piste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO pitkä ajatusviiva - tuplapiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO pitkä ajatusviiva - kolmoispiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO piste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO pitkäviiva - lyhytviiva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO pitkäviiva - tupla lyhytviiva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO viiva - piste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO tuplaviiva - piste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO viiva - tuplapiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO tuplaviiva - tuplapiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO ajatusviiva - kolmoispiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO pitkä ajatusviiva - kolmoispiste</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Kuuman veden jakelu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Kuuma vesi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Kaasuputki</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Vanu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Siksak</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Raidat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Aitalinja 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Aitalinja 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 1</source>
        <translation>Piste 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 2</source>
        <translation>Piste 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plant</source>
        <translation>Kasvi</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Water</source>
        <translation>Vesi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage</source>
        <translation>Viemäri</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Salaojitus käänteinen</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Communication</source>
        <translation>Viestintä</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Electric</source>
        <translation>Sähköinen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low Voltage</source>
        <translation>Pienjännite</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>High Voltage</source>
        <translation>Korkea jännite</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Overhead Power</source>
        <translation>Yläpuolinen teho</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Foul</source>
        <translation>Foul</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Foul Rising</source>
        <translation>Foul Rising</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+37"/>
        <source>By Layer</source>
        <translation>Tason mukaan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Lohkon mukaan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>Oletus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0.00 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0.05 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0.09 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0.13 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0.15 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0.18 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0.20 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0.25 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0.30 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0.35 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0.40 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0.50 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0.53 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0.60 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0.70 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0.80 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0.90 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1.00 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1.06 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1.20 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1.40 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1.58 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2.00 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2.11 mm</translation>
    </message>
</context>
</TS>
